summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/irc/libkirc/kircmessageredirector.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/irc/libkirc/kircmessageredirector.h')
-rw-r--r--kopete/protocols/irc/libkirc/kircmessageredirector.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kopete/protocols/irc/libkirc/kircmessageredirector.h b/kopete/protocols/irc/libkirc/kircmessageredirector.h
index f87a2af6..24a2f9af 100644
--- a/kopete/protocols/irc/libkirc/kircmessageredirector.h
+++ b/kopete/protocols/irc/libkirc/kircmessageredirector.h
@@ -18,8 +18,8 @@
#ifndef KIRC_MESSAGEREDIRECTOR_H
#define KIRC_MESSAGEREDIRECTOR_H
-#include <qobject.h>
-#include <qstring.h>
+#include <tqobject.h>
+#include <tqstring.h>
namespace KIRC
{
@@ -42,27 +42,27 @@ public:
MessageRedirector(KIRC::Engine *engine,
int argsSize_min = KIRC::MessageRedirector::Unknown,
int argsSize_max = KIRC::MessageRedirector::Unknown,
- const QString &helpMessage = QString::null);
+ const TQString &helpMessage = TQString::null);
/**
* Connects the given object member signal/slot to this message redirector.
* The member signal slot should be looking like:
- * SIGNAL(mysignal(KIRC::Message &msg))
+ * TQT_SIGNAL(mysignal(KIRC::Message &msg))
* or
- * SIGNAL(myslot(KIRC::Message &msg))
+ * TQT_SIGNAL(myslot(KIRC::Message &msg))
*/
- bool connect(QObject *object, const char *member);
+ bool connect(TQObject *object, const char *member);
/**
* Attempt to send the message.
* @return a not empty QStringList on errors or no slots connected.
* The returned string list contains all the errors.
*/
- QStringList operator()(KIRC::Message &msg);
+ TQStringList operator()(KIRC::Message &msg);
- void error(QString &errorMessage);
+ void error(TQString &errorMessage);
- QString helpMessage();
+ TQString helpMessage();
signals:
void redirect(KIRC::Message &);
@@ -74,11 +74,11 @@ private:
*/
bool checkValidity(const KIRC::Message &msg);
- QStringList m_errors;
+ TQStringList m_errors;
int m_argsSize_min;
int m_argsSize_max;
- QString m_helpMessage;
+ TQString m_helpMessage;
};
}
@@ -42,27 +42,27 @@ public:
/**
* Attempt to send the message.
- * @return a not empty QStringList on errors or no slots connected.
+ * @return a not empty TQStringList on errors or no slots connected.
* The returned string list contains all the errors.
*/